==> at_commons-2.0.5.tar.gz: test/sync_verb_builder_test.dart <==
import 'package:at_commons/at_builders.dart';
import 'package:at_commons/src/verb/sync_verb_builder.dart';
import 'package:test/test.dart';

void main() {
  test('build sync verb command with defaults values', () {
    var syncVerbBuilder = SyncVerbBuilder()..commitId = -1;
    var command = syncVerbBuilder.buildCommand();
    expect(command, 'sync:-1\n');
    var regex = RegExp(VerbSyntax.sync);
    command = command.replaceAll('\n', '');
    assert(regex.hasMatch(command));
  });

  test('build sync verb command with regex', () {
    var syncVerbBuilder = SyncVerbBuilder()
      ..regex = '.buzz'
      ..commitId = -1;
    var command = syncVerbBuilder.buildCommand();
    expect(command, 'sync:-1:.buzz\n');
    var regex = RegExp(VerbSyntax.sync);
    command = command.replaceAll('\n', '');
    assert(regex.hasMatch(command));
  });

  test('build sync verb command with commitId and regex', () {
    var syncVerbBuilder = SyncVerbBuilder()
      ..commitId = 3
      ..regex = '.buzz';
    var command = syncVerbBuilder.buildCommand();
    expect(command, 'sync:3:.buzz\n');
    var regex = RegExp(VerbSyntax.sync);
    command = command.replaceAll('\n', '');
    assert(regex.hasMatch(command));
  });

  test('build sync stream verb command with regex', () {
    var syncVerbBuilder = SyncVerbBuilder()
      ..commitId = 3
      ..regex = '.buzz'
      ..isStream = true;
    var command = syncVerbBuilder.buildCommand();
    expect(command, 'sync:stream:3:.buzz\n');
    var regex = RegExp(VerbSyntax.syncStream);
    command = command.replaceAll('\n', '');
    assert(regex.hasMatch(command));
  });

  test('build sync stream verb command', () {
    var syncVerbBuilder = SyncVerbBuilder()
      ..commitId = 3
      ..isStream = true;
    var command = syncVerbBuilder.buildCommand();
    expect(command, 'sync:stream:3\n');
    var regex = RegExp(VerbSyntax.syncStream);
    command = command.replaceAll('\n', '');
    assert(regex.hasMatch(command));
  });

  test('build sync stream verb command', () {
    var syncVerbBuilder = SyncVerbBuilder()
      ..isStream = true
      ..commitId = -1;
    var command = syncVerbBuilder.buildCommand();
    expect(command, 'sync:stream:-1\n');
    var regex = RegExp(VerbSyntax.syncStream);
    command = command.replaceAll('\n', '');
    assert(regex.hasMatch(command));
  });
}

==> at_commons-3.0.0.tar.gz: test/sync_verb_builder_test.dart <==
import 'package:at_commons/at_builders.dart';
import 'package:at_commons/src/verb/sync_verb_builder.dart';
import 'package:test/test.dart';

void main() {
  test('build sync verb command with defaults values', () {
    var syncVerbBuilder = SyncVerbBuilder()..commitId = -1;
    var command = syncVerbBuilder.buildCommand();
    expect(command, 'sync:-1\n');
    var regex = RegExp(VerbSyntax.sync);
    command = command.replaceAll('\n', '');
    assert(regex.hasMatch(command));
  });

  test('build sync verb command with regex', () {
    var syncVerbBuilder = SyncVerbBuilder()
      ..regex = '.buzz'
      ..commitId = -1;
    var command = syncVerbBuilder.buildCommand();
    expect(command, 'sync:-1:.buzz\n');
    var regex = RegExp(VerbSyntax.sync);
    command = command.replaceAll('\n', '');
    assert(regex.hasMatch(command));
  });

  test('build sync verb command with commitId and regex', () {
    var syncVerbBuilder = SyncVerbBuilder()
      ..commitId = 3
      ..regex = '.buzz';
    var command = syncVerbBuilder.buildCommand();
    expect(command, 'sync:3:.buzz\n');
    var regex = RegExp(VerbSyntax.sync);
    command = command.replaceAll('\n', '');
    assert(regex.hasMatch(command));
  });

  test('build sync stream verb command with regex', () {
    var syncVerbBuilder = SyncVerbBuilder()
      ..commitId = 3
      ..regex = '.buzz'
      ..isPaginated = true
      ..limit = 10;
    var command = syncVerbBuilder.buildCommand();
    expect(command, 'sync:from:3:limit:10:.buzz\n');
    var regex = RegExp(VerbSyntax.syncFrom);
    command = command.replaceAll('\n', '');
    assert(regex.hasMatch(command));
  });

  test('build sync stream verb command', () {
    var syncVerbBuilder = SyncVerbBuilder()
      ..commitId = 3
      ..isPaginated = true
      ..limit = 10;
    var command = syncVerbBuilder.buildCommand();
    expect(command, 'sync:from:3:limit:10\n');
    var regex = RegExp(VerbSyntax.syncFrom);
    command = command.replaceAll('\n', '');
    assert(regex.hasMatch(command));
  });

  test('build sync stream verb command', () {
    var syncVerbBuilder = SyncVerbBuilder()..commitId = -1..isPaginated = true..limit = 5;
    var command = syncVerbBuilder.buildCommand();
    expect(command, 'sync:from:-1:limit:5\n');
    var regex = RegExp(VerbSyntax.syncFrom);
    command = command.replaceAll('\n', '');
    assert(regex.hasMatch(command));
  });
}
